@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -33,10 +33,13 @@ class Quota(DriverPlugin):
 
         for resource, value in values.items():
             if resource in quotas:
-                if value >= quotas[resource]:
+                # Setting the resource quota to a negative value will make
+                # the resource unlimited
+                if quotas[resource] >= 0 and value > quotas[resource]:
                     raise exceptions.OverQuota()
             else:
-                raise exceptions.QuotaResourceUnknown()
+                raise exceptions.QuotaResourceUnknown("%s is not a valid quota"
+                                                      " resource", resource)
 
     def get_quotas(self, context, tenant_id):
         quotas = self.get_default_quotas(context)
@@ -51,9 +54,9 @@ class Quota(DriverPlugin):
 
     def get_default_quotas(self, context):
         return {
-            'domains': cfg.CONF.quota_domains,
-            'domain_recordsets': cfg.CONF.quota_domain_recordsets,
-            'domain_records': cfg.CONF.quota_domain_records,
+            'zones': cfg.CONF.quota_zones,
+            'zone_recordsets': cfg.CONF.quota_zone_recordsets,
+            'zone_records': cfg.CONF.quota_zone_records,
             'recordset_records': cfg.CONF.quota_recordset_records,
             'api_export_size': cfg.CONF.quota_api_export_size,
         }
@@ -62,7 +65,8 @@ class Quota(DriverPlugin):
         quotas = self._get_quotas(context, tenant_id)
 
         if resource not in quotas:
-            raise exceptions.QuotaResourceUnknown()
+            raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
+                                                  "resource", resource)
 
         return quotas[resource]
 
